@@ -1,25 +1,23 @@
 import asyncio
 
-from ...context import Context
-from ...provider import DefaultContextProvider
+from ...provider import BaseContextProvider
+from ...span import Span
 
 
-# Task attribute used to set/get the Context instance
-CONTEXT_ATTR = "__datadog_context"
-
-
-class AsyncioContextProvider(DefaultContextProvider):
-    """
-    Context provider that retrieves all contexts for the current asyncio
-    execution. It must be used in asynchronous programming that relies
-    in the built-in ``asyncio`` library. Framework instrumentation that
-    is built on top of the ``asyncio`` library, can use this provider.
+class AsyncioContextProvider(BaseContextProvider):
+    """Manages the active context for asyncio execution. Framework
+    instrumentation that is built on top of the ``asyncio`` library, should
+    use this provider when contextvars are not available (Python versions
+    less than 3.7).
 
     This Context Provider inherits from ``DefaultContextProvider`` because
     it uses a thread-local storage when the ``Context`` is propagated to
     a different thread, than the one that is running the async loop.
     """
 
+    # Task attribute used to set/get the context
+    _CONTEXT_ATTR = "__datadog_context"
+
     def activate(self, context, loop=None):
         """Sets the scoped ``Context`` for the current running ``Task``."""
         loop = self._get_loop(loop)
@@ -29,7 +27,8 @@ class AsyncioContextProvider(DefaultContextProvider):
 
         # the current unit of work (if tasks are used)
         task = asyncio.Task.current_task(loop=loop)
-        setattr(task, CONTEXT_ATTR, context)
+        if task:
+            setattr(task, self._CONTEXT_ATTR, context)
         return context
 
     def _get_loop(self, loop=None):
@@ -55,15 +54,11 @@ class AsyncioContextProvider(DefaultContextProvider):
         if task is None:
             return False
 
-        ctx = getattr(task, CONTEXT_ATTR, None)
+        ctx = getattr(task, self._CONTEXT_ATTR, None)
         return ctx is not None
 
     def active(self, loop=None):
-        """
-        Returns the scoped Context for this execution flow. The ``Context`` uses
-        the current task as a carrier so if a single task is used for the entire application,
-        the context must be handled separately.
-        """
+        """Returns the active context for the execution."""
         loop = self._get_loop(loop=loop)
         if not loop:
             return super(AsyncioContextProvider, self).active()
@@ -71,17 +66,8 @@ class AsyncioContextProvider(DefaultContextProvider):
         # the current unit of work (if tasks are used)
         task = asyncio.Task.current_task(loop=loop)
         if task is None:
-            # providing a detached Context from the current Task, may lead to
-            # wrong traces. This defensive behavior grants that a trace can
-            # still be built without raising exceptions
-            return Context()
-
-        ctx = getattr(task, CONTEXT_ATTR, None)
-        if ctx is not None:
-            # return the active Context for this task (if any)
-            return ctx
-
-        # create a new Context using the Task as a Context carrier
-        ctx = Context()
-        setattr(task, CONTEXT_ATTR, ctx)
+            return None
+        ctx = getattr(task, self._CONTEXT_ATTR, None)
+        if isinstance(ctx, Span):
+            return self._update_active(ctx)
         return ctx
