@@ -47,11 +47,13 @@ To configure particular redis instances use the :ref:`Pin<Pin>` API::
 
 from ...utils.importlib import require_modules
 
+
 required_modules = ["redis", "redis.client"]
 
 with require_modules(required_modules) as missing_modules:
     if not missing_modules:
         from .patch import patch
-        from .tracers import get_traced_redis, get_traced_redis_from
+        from .tracers import get_traced_redis
+        from .tracers import get_traced_redis_from
 
         __all__ = ["get_traced_redis", "get_traced_redis_from", "patch"]
